MySQLPoolRetryOptions class

Constructors

MySQLPoolRetryOptions({int maxAttempts = 1, Duration delay = const Duration(milliseconds: 50), bool retryIf(Object error)?})
const

Properties

delay → Duration
final
hashCode → int
The hash code for this object.
no setterinherited
maxAttempts → int
final
retryIf → bool Function(Object error)?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited