MySQLPoolStatus class

Constructors

MySQLPoolStatus({required int activeConnections, required int idleConnections, required int pendingConnections})
const

Properties

activeConnections int
final
hashCode int
The hash code for this object.
no setterinherited
idleConnections int
final
pendingConnections int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalConnections int
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited