MySQLPacketError class

Representa um pacote de erro do protocolo MySQL.

Esse pacote é enviado pelo servidor quando ocorre um erro durante a execução de uma requisição. Ele contém:

  • Um header que identifica o pacote como um erro.
  • Um código de erro (errorCode).
  • Uma mensagem de erro (errorMessage) detalhando o problema.
Inheritance

Constructors

MySQLPacketError({required int header, required int errorCode, required String errorMessage})
Construtor para criar uma instância de MySQLPacketError.
MySQLPacketError.decode(Uint8List buffer)
Decodifica um buffer Uint8List recebido do servidor e retorna uma instância de MySQLPacketError.
factory

Properties

errorCode → int
Código do erro, conforme definido pelo MySQL.
final
errorMessage → String
Mensagem descritiva do erro.
final
hashCode → int
The hash code for this object.
no setterinherited
Header do pacote (geralmente 0xff, indicando um pacote de erro).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Uint8List
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited