MySQLPacketStmtPrepareOK class

Representa o pacote de resposta ao comando COM_STMT_PREPARE (Prepare Statement OK) do protocolo MySQL.

Esse pacote é enviado pelo servidor em resposta à requisição de preparação de um statement, e contém informações necessárias para a execução do prepared statement, tais como:

  • Um header identificando o pacote.
  • Um ID único para o statement (stmtID).
  • O número de colunas que o statement irá retornar.
  • O número de parâmetros que o statement espera receber.
  • O número de warnings (se houver).
Inheritance

Constructors

MySQLPacketStmtPrepareOK({required int header, required int stmtID, required int numOfCols, required int numOfParams, required int numOfWarnings})
Construtor da classe.
MySQLPacketStmtPrepareOK.decode(Uint8List buffer)
Decodifica um buffer Uint8List recebido do servidor e retorna uma instância de MySQLPacketStmtPrepareOK.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
Header do pacote (geralmente 0x00).
final
numOfCols → int
Número de colunas que o statement retornará.
final
numOfParams → int
Número de parâmetros esperados pelo statement.
final
numOfWarnings → int
Número de warnings gerados durante a preparação do statement.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stmtID → int
ID único do statement gerado pelo servidor.
final

Methods

encode() → Uint8List
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited